/*
 * $Id: DowntownCounterFactory.java,v 1.1 2006/03/14 13:38:39 spindler Exp $
 * 
 *  Copyright (C) 2005 by Torsten Spindler
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Created on Feb 16, 2005
 */
package downtown;

import VASSAL.build.Buildable;
import VASSAL.build.Configurable;
import VASSAL.build.GameModule;
import VASSAL.build.module.BasicCommandEncoder;
import VASSAL.build.module.documentation.HelpFile;
import VASSAL.configure.Configurer;
import VASSAL.counters.Decorator;
import VASSAL.counters.GamePiece;

/**
 * Facility to create new counters for the Downtown module. Follows advice by Brent Easton. 
 * @since Feb 16, 2005
 * @author Torsten Spindler
 * @version $Id: DowntownCounterFactory.java,v 1.1 2006/03/14 13:38:39 spindler Exp $
 */
public class DowntownCounterFactory extends BasicCommandEncoder implements Configurable {
    
    public Decorator createDecorator(String type, GamePiece inner) {
        Decorator piece = null;
        if (type.startsWith(Activator.ID)) {
            piece = new Activator(type,inner);
        } else if (type.startsWith(HideableCustomizable.ID)) {
        	piece = new HideableCustomizable(type,inner);
        }
        else {
            piece = super.createDecorator(type,inner);
        }
        return piece;
    }
 
    public void removeFrom(Buildable parent) {
        GameModule.getGameModule().removeCommandEncoder(this);
    }
 
 
    public void remove(Buildable child) {}
 
    public String getConfigureName() {
      return "Downtown Counter Factory";
    }
 
    public HelpFile getHelpFile() {
      return null;
    }
 
    public Configurable[] getConfigureComponents() {
      return new Configurable[0];
    }
 
    public Configurer getConfigurer() {
      return null;
    }
 
    public Class[] getAllowableConfigureComponents() {
      return new Class[0];
    }
 
    public void addPropertyChangeListener(java.beans.PropertyChangeListener l) {}


}
