package downtown;

/**
 * HideAccess is the interface for implementing strategies to hide gamepieces.
 * @author spindler
 *
 */
public interface HideAccessInterface {

	/**
	 * Set the strategy to access hidden pieces.
	 * @param strategy provides methods to get the secret and check for access, see below.
	 */
	public void setHideStrategy(HideAccessStrategy strategy);
	
	/**
	 * Get the secret, e.g. password for hiding.
	 * @return the secret.
	 */
	public String getSecret();
	
	/**
	 * Check if access is granted based on secret in the gamepiece.
	 * @param secret contains the value stored in the gamepiece.
	 * @return true if access is granted, false otherwise.
	 */
	public boolean hasAccess(String secret);

	/**
	 * Check if there is any option for access. Option can be a side.
	 * @return true if there's an option, false othweise.
	 */
	public boolean hasOption();
	
	/**
	 * Probably misleading name, return the strategies type or 'none'.
	 * @return
	 */
	public String myGetType();
}
