package downtown;

/**
 * Interface for implementing strategies to be used by Hideable.
 * @author spindler
 *
 */
public interface HideAccessStrategy {
	/**
	 * Get the secret that needs to be known by everybody seeing the piece.
	 * @return the secret based on chosen strategy.
	 */
	public String getSecret();
	/**
	 * Check if the supplied secret of the gamepiece can be matched by the player.
	 * The way the check is done depends on strategy, it can be either an attribute
	 * of the player or a stored attribute.
	 * @param secret is the gamepieces hiddenBy field
	 * @return true if access is granted, false otherwise
	 */
	public boolean hasAccess(String secret);
	/**
	 * The type is presented in a non Vassal fashion with : as seperator between
	 * strategy and any further information.
	 * @return a String defining the strategy and any attributes
	 */
	public String myGetType();
	/**
	 * Set additional information that might be needed. Probably be better call setType?
	 * @param information contains the attributes information
	 */
	public void setOption(String information);
	
	public boolean hasOption();
}
